==> haskell-hjsonpointer-1.4.0-30-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hjsonpointer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hjsonpointer
version: 1.4.0
id: hjsonpointer-1.4.0-G1mWJS8cbQt7TmlNGqLhIO
key: hjsonpointer-1.4.0-G1mWJS8cbQt7TmlNGqLhIO
license: MIT
maintainer: ian@housejeffries.com
author: Ian Grant Jeffries
homepage: https://github.com/seagreen/hjsonpointer
synopsis: JSON Pointer library
category: Data
abi: 74b0065f24db7a740f0daca19413460e
exposed: True
exposed-modules:
    JSONPointer
import-dirs: /usr/lib/ghc-8.4.3/site-local/hjsonpointer-1.4.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/hjsonpointer-1.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/hjsonpointer-1.4.0
hs-libraries: HShjsonpointer-1.4.0-G1mWJS8cbQt7TmlNGqLhIO
depends:
    base-4.11.1.0 aeson-1.4.0.0-LGp6kTtgO3W1vagljwPVLq
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr
    unordered-containers-0.2.9.0-FkHC8tkjGhFEq6gcD4EsVo text-1.2.3.0
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             aeson-1.4.0.0-LGp6kTtgO3W1vagljwPVLq=0bddb8c122a0181e324f08c1b045cf5c
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=ad8d36b5596969152937469512f0d3b1
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=0b62adbb61d61aac8d449588192e831b
             unordered-containers-0.2.9.0-FkHC8tkjGhFEq6gcD4EsVo=64a561e4e9a96e6da50de53181f89cb1
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
haddock-interfaces: /usr/share/doc/haskell-hjsonpointer/html/hjsonpointer.haddock
haddock-html: /usr/share/doc/haskell-hjsonpointer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hjsonpointer-1.4.0-39-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hjsonpointer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hjsonpointer
version: 1.4.0
id: hjsonpointer-1.4.0-4rlHp47mOQKGmdtHTw8R3I
key: hjsonpointer-1.4.0-4rlHp47mOQKGmdtHTw8R3I
license: MIT
maintainer: ian@housejeffries.com
author: Ian Grant Jeffries
homepage: https://github.com/seagreen/hjsonpointer
synopsis: JSON Pointer library
category: Data
abi: ad0b6b78f7b4897bf768daf36062b0d4
exposed: True
exposed-modules:
    JSONPointer
import-dirs: /usr/lib/ghc-8.4.3/site-local/hjsonpointer-1.4.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/hjsonpointer-1.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/hjsonpointer-1.4.0
hs-libraries: HShjsonpointer-1.4.0-4rlHp47mOQKGmdtHTw8R3I
depends:
    base-4.11.1.0 aeson-1.4.1.0-Je86IRhAZ9i9fcEQGpo4BI
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr
    unordered-containers-0.2.9.0-EtLPGprUM82GTPrcqDz1YE text-1.2.3.0
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             aeson-1.4.1.0-Je86IRhAZ9i9fcEQGpo4BI=e763a4a7c222101a91911389c36d4497
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=ad8d36b5596969152937469512f0d3b1
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=0b62adbb61d61aac8d449588192e831b
             unordered-containers-0.2.9.0-EtLPGprUM82GTPrcqDz1YE=d999168fa5a35d048ce4f3e0442b4ae6
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
haddock-interfaces: /usr/share/doc/haskell-hjsonpointer/html/hjsonpointer.haddock
haddock-html: /usr/share/doc/haskell-hjsonpointer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
